@@ -38,19 +38,10 @@ loader.lazyRequireGetter(
   "resource://devtools/shared/async-storage.js"
 );
 
-const CSS_GRID_COUNT_HISTOGRAM_ID = "DEVTOOLS_NUMBER_OF_CSS_GRIDS_IN_A_PAGE";
-
 const SHOW_GRID_AREAS = "devtools.gridinspector.showGridAreas";
 const SHOW_GRID_LINE_NUMBERS = "devtools.gridinspector.showGridLineNumbers";
 const SHOW_INFINITE_LINES_PREF = "devtools.gridinspector.showInfiniteLines";
 
-const TELEMETRY_GRID_AREAS_OVERLAY_CHECKED =
-  "devtools.grid.showGridAreasOverlay.checked";
-const TELEMETRY_GRID_LINE_NUMBERS_CHECKED =
-  "devtools.grid.showGridLineNumbers.checked";
-const TELEMETRY_INFINITE_LINES_CHECKED =
-  "devtools.grid.showInfiniteLines.checked";
-
 // Default grid colors.
 const GRID_COLORS = [
   "#9400FF",
@@ -174,7 +165,7 @@ class GridInspector {
     this.inspector.sidebar.off("select", this.onSidebarSelect);
     this.inspector.off("new-root", this.onNavigate);
 
-    this.inspector.off("reflow-in-selected-target", this.onReflow);
+    this.inspector.off("reflow", this.onReflow);
 
     this._highlighters = null;
     this.document = null;
@@ -336,9 +327,9 @@ class GridInspector {
 
     // Log how many CSS Grid elements DevTools sees.
     if (currentUrl != this.inspector.previousURL) {
-      this.telemetry
-        .getHistogramById(CSS_GRID_COUNT_HISTOGRAM_ID)
-        .add(gridFronts.length);
+      Glean.devtoolsInspector.numberOfCssGridsInAPage.accumulateSingleSample(
+        gridFronts.length
+      );
       this.inspector.previousURL = currentUrl;
     }
 
@@ -403,9 +394,8 @@ class GridInspector {
         let parentGridNodeFront;
 
         try {
-          parentGridNodeFront = await nodeFront.walkerFront.getParentGridNode(
-            nodeFront
-          );
+          parentGridNodeFront =
+            await nodeFront.walkerFront.getParentGridNode(nodeFront);
         } catch (e) {
           // This call might fail if called asynchrously after the toolbox is finished
           // closing.
@@ -639,11 +629,13 @@ class GridInspector {
    */
   onSidebarSelect() {
     if (!this.isPanelVisible()) {
-      this.inspector.off("reflow-in-selected-target", this.onReflow);
+      this.inspector.off("reflow", this.onReflow);
       return;
     }
 
-    this.inspector.on("reflow-in-selected-target", this.onReflow);
+    // The panel shows grids from all debugged document, so we need to listen for the
+    // `reflow` event (and not `reflow-in-selected-target`).
+    this.inspector.on("reflow", this.onReflow);
     this.updateGridPanel();
   }
 
@@ -674,10 +666,6 @@ class GridInspector {
     this.store.dispatch(updateShowGridAreas(enabled));
     Services.prefs.setBoolPref(SHOW_GRID_AREAS, enabled);
 
-    if (enabled) {
-      this.telemetry.scalarSet(TELEMETRY_GRID_AREAS_OVERLAY_CHECKED, 1);
-    }
-
     const { grids } = this.store.getState();
 
     for (const grid of grids) {
@@ -700,10 +688,6 @@ class GridInspector {
     this.store.dispatch(updateShowGridLineNumbers(enabled));
     Services.prefs.setBoolPref(SHOW_GRID_LINE_NUMBERS, enabled);
 
-    if (enabled) {
-      this.telemetry.scalarSet(TELEMETRY_GRID_LINE_NUMBERS_CHECKED, 1);
-    }
-
     const { grids } = this.store.getState();
 
     for (const grid of grids) {
@@ -726,10 +710,6 @@ class GridInspector {
     this.store.dispatch(updateShowInfiniteLines(enabled));
     Services.prefs.setBoolPref(SHOW_INFINITE_LINES_PREF, enabled);
 
-    if (enabled) {
-      this.telemetry.scalarSet(TELEMETRY_INFINITE_LINES_CHECKED, 1);
-    }
-
     const { grids } = this.store.getState();
 
     for (const grid of grids) {
